@@ -247,17 +247,6 @@ class WebHelpers(BrowserView):
         # to be overwritten as needed
         return self.use_locking_feature
 
-    @property
-    @memoize
-    @deprecate(
-        "Deprecated in version 18.2.1.dev0. "
-        "The feature will be always enabled in the future."
-    )
-    def use_clone_feature(self):
-        return api.portal.get_registry_record(
-            "euphorie.use_clone_feature", default=True
-        )
-
     @property
     @memoize
     def use_archive_feature(self):
@@ -1147,11 +1136,6 @@ class WebHelpers(BrowserView):
     def can_unlock_session(self):
         return self.can_lock_session
 
-    @property
-    @memoize
-    def can_duplicate_session(self):
-        return self.use_clone_feature
-
     def resume(self, session):
         """Resume a session for the current user if he is allowed to."""
         raise Exception("Obsolete, we traverse to sessions now")
